v2.2 - Nautobot Design Builder Documentation

Skip to content

# v2.2.0 Release Notes

## Release Overview

The 2.2.0 release of Design Builder introduces a change in the Jinja2 filters location according to Nautobot standards.

Before this release, the Jinja2 filters were located in the `nautobot_design_builder.jinja2` module. This release moves the filters to the `nautobot_design_builder.jinja_filters` module.

## v2.2.0 (2025-03-25)

### Added

- #200 - Error reporting for custom relationships that introduce duplicate fields

### Fixed

- #203 - Provided a default value for the `dry_run` keyword argument
- #214 - Provided a default value for the `dry_run` keyword argument
- #217 - Fix APIView tests overwritting `test_list_objects_depth_0`
- #218 - Fix issue with model of with attribute of `filter` overlapping with `ModelMetadata` class.

### Housekeeping

- #196 - Updates docs dependencies to cookiecutter versions so the RTD build will pass.
- #196 - Fixes #187, removing Nautobot as an extra and setting the upper bound to 3.0.
- #201 - Refactored jinja2 filters to Nautobot standard location
- #202 - Adds tests for properties in render contexts
- #221 - Rebake the testing dependencies from the cookie to get docs working.